==> moodle-2.9.4.zip: moodle/repository/flickr/lang/en/repository_flickr.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'repository_flickr', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   repository_flickr
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['apikey'] = 'API key';
$string['callbackurl'] = 'Callback URL';
$string['callbackurltext'] = '<ol>
<li>Visit <a href="http://www.flickr.com/services/api/keys/">Flickr API Keys</a> again.</li>
<li>Make sure you set the callback URL for this Flickr key as <strong>{$a}</strong></li></ol>';
$string['callbackwarning'] = '<ol>
<li>Get a <a href="http://www.flickr.com/services/api/keys/">Flickr API Key and Secret</a> from Flickr for this Moodle site.</li>
<li>Enter those details here, then click Save and then Settings to come back to this page.  You will see that Moodle has generated a callback URL for you.</li>
<li>Edit your <a href="http://www.flickr.com/services/api/keys/">Flickr</a> key details again and set the callback URL.</li></ol>';
$string['configplugin'] = 'Flickr configuration';
$string['emailaddress'] = 'Email address';
$string['flickr:view'] = 'View Flickr repository';
$string['invalidemail'] = 'Invalid email address for flickr';
$string['notitle'] = 'notitle';
$string['nullphotolist'] = 'There are no photos in this account';
$string['remember'] = 'Remember me';
$string['pluginname_help'] = 'Repository on flickr.com';
$string['pluginname'] = 'Flickr';
$string['secret'] = 'Secret';
$string['username'] = 'Flickr account email';

==> moodle-3.8.2.zip: moodle/repository/flickr/lang/en/repository_flickr.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'repository_flickr', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   repository_flickr
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['apikey'] = 'API key';
$string['callbackurl'] = 'Callback URL';
$string['callbackurltext'] = '<ol>
<li>Visit <a href="http://www.flickr.com/services/api/keys/">Flickr API Keys</a> again.</li>
<li>Make sure you set the callback URL for this Flickr key as <strong>{$a}</strong></li></ol>';
$string['callbackwarning'] = '<ol>
<li>Get a <a href="http://www.flickr.com/services/api/keys/">Flickr API Key and Secret</a> from Flickr for this Moodle site.</li>
<li>Enter those details here, then click Save and then Settings to come back to this page.  You will see that Moodle has generated a callback URL for you.</li>
<li>Edit your <a href="http://www.flickr.com/services/api/keys/">Flickr</a> key details again and set the callback URL.</li></ol>';
$string['configplugin'] = 'Flickr configuration';
$string['emailaddress'] = 'Email address';
$string['flickr:view'] = 'View Flickr repository';
$string['invalidemail'] = 'Invalid email address for flickr';
$string['notitle'] = 'notitle';
$string['nullphotolist'] = 'There are no photos in this account';
$string['remember'] = 'Remember me';
$string['pluginname_help'] = 'Repository on flickr.com';
$string['pluginname'] = 'Flickr';
$string['secret'] = 'Secret';
$string['username'] = 'Flickr account email';
$string['privacy:metadata:repository_flickr'] = 'The Flickr repository plugin does store user preferences, and transmits user data from Moodle to the remote system.';
$string['privacy:metadata:repository_flickr:text'] = 'The Flickr repository user search text query.';
$string['privacy:metadata:repository_flickr:preference:repository_flickr_access_token'] = 'The Flickr repository OAuth token preference.';
$string['privacy:metadata:repository_flickr:preference:repository_flickr_access_token_secret'] = 'The Flickr repository OAuth secret preference; this is excluded from privacy data exports.';
